Change "mctp instance id" to "pldm instance id"
Instance IDs are the ids given from the instanceID database
to the PLDM request and response messages.
Its not a MCTP thing but rather related to the PLDM messages.
Change-Id: I6eda652ec86cba691b8b2b848ca0c9227e4c05dc
Signed-off-by: Pavithra Barithaya <pavithrabarithaya07@gmail.com>
diff --git a/util/pldm.cpp b/util/pldm.cpp
index bbf2ce7..c161e51 100644
--- a/util/pldm.cpp
+++ b/util/pldm.cpp
@@ -50,9 +50,9 @@
uint16_t effecterId, uint8_t effecterCount, uint8_t stateIdPos,
uint8_t stateSetValue, uint8_t mctpEid)
{
- // get mctp instance associated with the endpoint ID
- uint8_t mctpInstance;
- if (!util::dbus::getMctpInstance(mctpInstance, mctpEid))
+ // get pldm instance associated with the endpoint ID
+ uint8_t pldmInstanceID;
+ if (!util::dbus::getPldmInstanceID(pldmInstanceID, mctpEid))
{
return std::vector<uint8_t>();
}
@@ -81,7 +81,8 @@
// encode the message with state data
auto requestMsg = reinterpret_cast<pldm_msg*>(request.data());
auto rc = encode_set_state_effecter_states_req(
- mctpInstance, effecterId, effecterCount, stateField.data(), requestMsg);
+ pldmInstanceID, effecterId, effecterCount, stateField.data(),
+ requestMsg);
if (rc != PLDM_SUCCESS)
{